@@ -29,14 +29,11 @@ has max         => (is => 'ro', isa => 'Num', default => 4);
 
 has timeout     => (is => 'ro', isa => 'Num', default => 60.0);
 
-our $VERSION = '0.026'; # VERSION
+our $VERSION = '0.027'; # VERSION
 
 sub BUILD {
     my ($self) = @_;
 
-    confess 'Net::Curl::Multi is missing timer callback, rebuild Net::Curl with libcurl 7.16.0 or newer'
-        unless $self->can('CURLMOPT_TIMERFUNCTION');
-
     $self->setopt(Net::Curl::Multi::CURLMOPT_MAXCONNECTS        => $self->max << 2);
     $self->setopt(Net::Curl::Multi::CURLMOPT_SOCKETFUNCTION     => \&_cb_socket);
     $self->setopt(Net::Curl::Multi::CURLMOPT_TIMERFUNCTION      => \&_cb_timer);
@@ -64,16 +61,16 @@ sub _cb_socket {
     my $keep = 0;
 
     # register read event
-    if (($poll == Net::Curl::Multi::CURL_POLL_IN) or ($poll == Net::Curl::Multi::CURL_POLL_INOUT)) {
-        $self->pool->{"r$socket"} //= AE::io $socket, 0, sub {
+    if ($poll & Net::Curl::Multi::CURL_POLL_IN) {
+        $self->pool->{"r$socket"} = AE::io $socket, 0, sub {
             $self->socket_action($socket, Net::Curl::Multi::CURL_CSELECT_IN);
         };
         ++$keep;
     }
 
     # register write event
-    if (($poll == Net::Curl::Multi::CURL_POLL_OUT) or ($poll == Net::Curl::Multi::CURL_POLL_INOUT)) {
-        $self->pool->{"w$socket"} //= AE::io $socket, 1, sub {
+    if ($poll & Net::Curl::Multi::CURL_POLL_OUT) {
+        $self->pool->{"w$socket"} = AE::io $socket, 1, sub {
             $self->socket_action($socket, Net::Curl::Multi::CURL_CSELECT_OUT);
         };
         ++$keep;
@@ -98,7 +95,8 @@ sub _cb_timer {
     $self->timer(undef);
 
     my $cb = sub {
-        $self->socket_action(Net::Curl::Multi::CURL_SOCKET_TIMEOUT);
+        $self->socket_action(Net::Curl::Multi::CURL_SOCKET_TIMEOUT)
+            if $self->handles > 0;
     };
 
     if ($timeout_ms < 0) {
@@ -112,8 +110,7 @@ sub _cb_timer {
         # must not wait too long (more than a few seconds perhaps)
         # before you call curl_multi_perform() again.
 
-        $self->timer(AE::timer 1, 1, $cb)
-            if $self->handles > 0;
+        $self->timer(AE::timer 1, 1, $cb);
     } else {
         # This will trigger timeouts if there are any.
         $self->timer(AE::timer $timeout_ms / 1000, 0, $cb);
@@ -133,13 +130,9 @@ sub socket_action {
     $self->active($self->SUPER::socket_action(@_));
 
     my $i = 0;
-    while (my ($msg, $easy, $result) = $self->info_read) {
-        if ($msg == Net::Curl::Multi::CURLMSG_DONE) {
-            $self->remove_handle($easy);
-            $easy->_finish($result);
-        } else {
-            confess "I don't know what to do with message $msg";
-        }
+    while (my (undef, $easy, $result) = $self->info_read) {
+        $self->remove_handle($easy);
+        $easy->_finish($result);
     } continue {
         ++$i;
     }
@@ -156,9 +149,6 @@ sub add_handle {
     my $self = shift;
     my $easy = shift;
 
-    confess "Can't _finish()"
-        unless $easy->can('_finish');
-
     #my $r = $self->$orig($easy);
     my $r = $self->SUPER::add_handle($easy);
 
@@ -173,7 +163,7 @@ sub add_handle {
     # persistent connections and server returned data right away)
     # and it could confuse our application -- it would appear to
     # have finished before it started.
-    AE::timer 0, 0, sub {
+    AE::postpone {
         $self->socket_action;
     };
 
@@ -198,7 +188,7 @@ AnyEvent::Net::Curl::Queued::Multi - Net::Curl::Multi wrapped by Any::Moose
 
 =head1 VERSION
 
-version 0.026
+version 0.027
 
 =head1 SYNOPSIS
 
